@@ -68,6 +68,16 @@ define([
         this.state.go('overview')
       }
 
+      const DEFAULT_KPI_VALUE = '-'
+      this.scope.lastNotChecked = DEFAULT_KPI_VALUE
+      this.scope.lastPass = DEFAULT_KPI_VALUE
+      this.scope.lastScanScore = DEFAULT_KPI_VALUE
+      this.scope.lastScanDate = DEFAULT_KPI_VALUE
+      this.scope.lastErrors = DEFAULT_KPI_VALUE
+      this.scope.lastFails = DEFAULT_KPI_VALUE
+      this.scope.lastUnknown = DEFAULT_KPI_VALUE
+      this.scope.lastScanBenchmark = DEFAULT_KPI_VALUE
+
       this.scope.reportingEnabled = reportingEnabled
       this.scope.extensions = extensions
       this.agent = agent
