@@ -1,16 +1,16 @@
-define(['../module'], function(module) {
+define(['../module'], function (module) {
   'use strict'
 
-  module.service('$tableFilterService', function() {
+  module.service('$tableFilterService', function () {
     const filters = []
     return {
-      set: array => {
+      set: (array) => {
         if (Array.isArray(array)) {
           filters.length = 0
           filters.push(...array)
         }
       },
-      get: () => filters
+      get: () => filters,
     }
   })
 })
